BiasCorrection <- function(var_obs, var_exp) {
  # Simple bias correction as in Torralba et al. 2017
  # Journal of Applied Meteorology and Climatology
  
  ntime <- length(var_obs)
    if (dim(var_exp)[1]!=dim(var_exp)[2]){
    nmembers <- dim(var_exp)[-which(dim(var_exp) == length(var_obs))]
  }else{
    nmembers<-dim(var_exp)[1]
  }
  
  if (!all(dim(var_exp)== c(nmembers, ntime))) {
    var_exp <- t(var_exp)
  }
  
  corrected <- NA * var_exp
  
  for (t in 1:ntime) {
    # defining forecast,hindcast and observation in cross-validation
    fcst <- var_exp[, t]
    hcst <- var_exp[,-t]
    obs <- var_obs[-t]
    
    # parameters
    sd_obs <- sd(obs)
    sd_exp <- sd(hcst)
    clim_exp <- mean(hcst)
    clim_obs <- mean(obs)
    
    # bias corrected forecast
    corrected[, t] <- ((fcst - clim_exp) * (sd_obs / sd_exp)) + clim_obs
  }
  
  return(corrected)
}
